@@ -7,17 +7,20 @@ An elmish architecture for fltk-rs.
 Add flemish to your dependencies:
 ```toml,ignore
 [dependencies]
-flemish = "0.1"
+flemish = "0.3"
 ```
 
 A usage example:
 ```rust,no_run
-use flemish::{button::Button, frame::Frame, prelude::*, Flex, OnEvent, Sandbox, Settings};
+use flemish::{
+    button::Button, color_themes, frame::Frame, group::Flex, prelude::*, OnEvent, Sandbox, Settings,
+};
 
 pub fn main() {
     Counter::new().run(Settings {
         size: (300, 100),
         resizable: true,
+        color_map: Some(color_themes::BLACK_THEME),
         ..Default::default()
     })
 }
@@ -55,15 +58,16 @@ impl Sandbox for Counter {
         }
     }
 
-    fn view(&mut self) -> Flex {
-        let mut col = Flex::default().column();
-        let mut button1 = Button::default().with_label("Increment");
-        button1.on_event(Message::IncrementPressed);
+    fn view(&mut self) {
+        let col = Flex::default_fill().column();
+        Button::default()
+            .with_label("Increment")
+            .on_event(Message::IncrementPressed);
         Frame::default().with_label(&self.value.to_string());
-        let mut button2 = Button::default().with_label("Decrement");
-        button2.on_event(Message::DecrementPressed);
+        Button::default()
+            .with_label("Decrement")
+            .on_event(Message::DecrementPressed);
         col.end();
-        col
     }
 }
 ```
@@ -72,7 +76,6 @@ impl Sandbox for Counter {
 
 use fltk::prelude::*;
 pub use fltk::*;
-pub use fltk_flex::*;
 pub use fltk_theme::*;
 
 pub trait OnEvent<W, T>
@@ -80,7 +83,9 @@ where
     W: WidgetExt,
     T: Send + Sync + Clone + 'static,
 {
-    fn on_event(&mut self, msg: T);
+    fn on_event(self, msg: T) -> Self
+    where
+        Self: Sized;
 }
 
 impl<W, T> OnEvent<W, T> for W
@@ -88,9 +93,10 @@ where
     W: WidgetExt,
     T: Send + Sync + Clone + 'static,
 {
-    fn on_event(&mut self, msg: T) {
+    fn on_event(mut self, msg: T) -> Self {
         let (s, _) = app::channel::<T>();
         self.emit(s, msg);
+        self
     }
 }
 
@@ -115,7 +121,7 @@ pub trait Sandbox {
     type Message: Clone + Send + Sync;
     fn new() -> Self;
     fn title(&self) -> String;
-    fn view(&mut self) -> Flex;
+    fn view(&mut self);
     fn update(&mut self, message: Self::Message);
     fn run(&mut self, settings: Settings) {
         let a = app::App::default();
@@ -178,7 +184,7 @@ pub trait Sandbox {
         while a.wait() {
             if let Some(msg) = r.recv() {
                 self.update(msg);
-                win.remove_by_index(0);
+                win.clear();
                 win.begin();
                 self.view();
                 win.end();
